<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="442"/>
        <location filename="../../CopyEngine.cpp" line="465"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>Le moteur est forcé en déplacement, vous ne pouvez pas copier avec</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="519"/>
        <location filename="../../CopyEngine.cpp" line="542"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>Le moteur est forcé en copie, vous ne pouvez pas déplacer avec</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>Utiliser la destination actuelle &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="731"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>Le mode a été forcé. C&apos;est une erreur interne, merci de la repporter</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="886"/>
        <source>Supported only on Windows</source>
        <translation>Pris en charge uniquement sous Windows</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1035"/>
        <location filename="../../CopyEngine.cpp" line="1038"/>
        <location filename="../../CopyEngine.cpp" line="1043"/>
        <location filename="../../CopyEngine.cpp" line="1047"/>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1036"/>
        <location filename="../../CopyEngine.cpp" line="1040"/>
        <location filename="../../CopyEngine.cpp" line="1044"/>
        <location filename="../../CopyEngine.cpp" line="1048"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1039"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1041"/>
        <location filename="../../CopyEngine.cpp" line="1053"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1045"/>
        <source>Put at the end</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1049"/>
        <source>Overwrite</source>
        <translation>Écraser</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1050"/>
        <source>Overwrite if different</source>
        <translation>Écraser si différent</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1051"/>
        <source>Overwrite if newer</source>
        <translation>Écraser si plus récent</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1052"/>
        <source>Overwrite if older</source>
        <translation>Écraser si plus vieux</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options error</source>
        <translation>Erreur d&apos;options</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Le moteur d&apos;options n&apos;est pas chargé. Impossible d&apos;accédé aux filtres</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="60"/>
        <location filename="../../CopyEngineFactory.cpp" line="309"/>
        <source>Supported only on Windows</source>
        <translation>Pris en charge uniquement sous Windows</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <location filename="../../CopyEngineFactory.cpp" line="454"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="446"/>
        <source>Put at the end</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="450"/>
        <source>Overwrite</source>
        <translation>Écraser</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="451"/>
        <source>Overwrite if different</source>
        <translation>Écraser si différent</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="452"/>
        <source>Overwrite if newer</source>
        <translation>Écraser si plus récent</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="453"/>
        <source>Overwrite if older</source>
        <translation>Écraser si plus vieux</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options error</source>
        <translation>Erreur d&apos;options</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Le moteur d&apos;options n&apos;est pas chargé. Impossible d&apos;accédé aux filtres</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>Moteur d&apos;options non chargé, impossible d&apos;accéder aux filtres</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>Espace disque</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>Vous avez besoin de plus d&apos;espace pour finir ce transfert</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>Lecteur %1 as %2 disponible mais à besoin de %3</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="92"/>
        <source>Error on folder</source>
        <translation>Erreur sur un dossier</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="95"/>
        <source>Folder name</source>
        <translation>Nom de répertoire</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="201"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copie%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="208"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copie (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="145"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copie%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="152"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copie (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>Recherche:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>Type de recherche:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Regex simplifiée</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Regex perl</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>Appliquer sur:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>Fichier et dossier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>La chaine de texte corresponds avec la regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>Vérification</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>Chaine de test:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>Dialogue des filtres</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>Toute la chaine doit correspondre</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>La regex est valid</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>Filtres</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="39"/>
        <source>Exclusion filters</source>
        <translation>Filtres d&apos;exclusion</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="111"/>
        <source>Inclusion filters</source>
        <translation>Filtres d&apos;inclusion</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="132"/>
        <source>None = Include all</source>
        <translation>Aucun = tout inclure</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="94"/>
        <location filename="../../Filters.cpp" line="132"/>
        <source>Raw text</source>
        <translation>Texte brute</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="97"/>
        <location filename="../../Filters.cpp" line="135"/>
        <source>Simplified regex</source>
        <translation>Regex simplifié</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="100"/>
        <location filename="../../Filters.cpp" line="138"/>
        <source>Perl&apos;s regex</source>
        <translation>Regex perl</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="108"/>
        <location filename="../../Filters.cpp" line="146"/>
        <source>Only on file</source>
        <translation>Appliquer sur fichier</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="111"/>
        <location filename="../../Filters.cpp" line="149"/>
        <source>Only on folder</source>
        <translation>Appliquer sur dossier</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="117"/>
        <location filename="../../Filters.cpp" line="155"/>
        <location filename="../../Filters.cpp" line="217"/>
        <location filename="../../Filters.cpp" line="256"/>
        <source>Full match</source>
        <translation>Correspondance totale</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="91"/>
        <source>Folder already exists</source>
        <translation>Dossier déjà existant</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="172"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copie%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="181"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copie (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="242"/>
        <location filename="../../ListThreadListChange.cpp" line="413"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>Impossible de faire un déplacement ou une copie dans le mauvais mode forcé: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="249"/>
        <location filename="../../ListThreadListChange.cpp" line="420"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>Impossible de sauvegarder la liste de transfert: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="270"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>Problem durant la lecture, ou taille de fichier est 0</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="277"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>Mauvais en-tête: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="286"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode mixte, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="295"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode copie, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="301"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode déplacement, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="365"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>Certaine erreur ont été trouvé durant l&apos;analise de la line</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="373"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>Impossible d&apos;ouvrir la list de transfert: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="187"/>
        <location filename="../../MkPath.cpp" line="210"/>
        <location filename="../../MkPath.cpp" line="315"/>
        <location filename="../../MkPath.cpp" line="363"/>
        <source>Unable to create the folder</source>
        <translation>Impossible de créer le répertoire</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="227"/>
        <source>The source folder don&apos;t exists</source>
        <translation>Le dossier source n&apos;éxiste pas</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="304"/>
        <source>Unable to temporary rename the folder</source>
        <translation>Impossible de renommer le dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="339"/>
        <source>Unable to reverse temporary rename for real move</source>
        <translation>Impossible d&apos;inverser le renommage temporaire pour un déplacement réel</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="348"/>
        <source>Unable to do the final real move the folder</source>
        <translation>Impossible de faire le déplacement final du dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="379"/>
        <source>Unable to move the folder</source>
        <translation>Impossible de déplacer le dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="385"/>
        <source>Unable to move the folder: errno: %1</source>
        <translation>Impossible de déplacer le dossier: errno: %1</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="124"/>
        <location filename="../../MkPath.cpp" line="464"/>
        <source>Unable to remove</source>
        <translation>Impossible de supprimer</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../async/ReadThread.cpp" line="78"/>
        <source>Internal error, please report it!</source>
        <translation>Erreur interne, veuillez la signaler!</translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="543"/>
        <source>Unable to read the source file: </source>
        <translation>Impossible de lire le fichier source: </translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="599"/>
        <source>File truncated during the read, possible data change</source>
        <translation>Fichier tronqué lors de la lecture, modification possible des données</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>Premier renommage</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation>%name% - copie%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>%name% - copie (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; pour le nom original, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; pour le numero extra, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>Second renommage</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>Règles de renommage</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="46"/>
        <location filename="../../RenamingRules.cpp" line="71"/>
        <source>%1 - copy%2</source>
        <translation>%1 - copie%2</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="50"/>
        <location filename="../../RenamingRules.cpp" line="84"/>
        <source>%1 - copy (%2)%3</source>
        <translation>%1 - copie (%2) {1 ?} {2)%3?}</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="331"/>
        <location filename="../../ScanFileOrFolder.cpp" line="681"/>
        <source>Blacklisted folder</source>
        <translation>Dossier sur liste noire</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="463"/>
        <location filename="../../ScanFileOrFolder.cpp" line="465"/>
        <source>%1 - copy</source>
        <translation>%1 - copie</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="474"/>
        <location filename="../../ScanFileOrFolder.cpp" line="476"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copie (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
        <source>%name% - copy</source>
        <translation>%name% - copie</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="598"/>
        <location filename="../../ScanFileOrFolder.cpp" line="600"/>
        <source>%name% - copy (%number%)</source>
        <translation>%name% - copie (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="691"/>
        <location filename="../../ScanFileOrFolder.cpp" line="695"/>
        <source>Problem with folder read</source>
        <translation>Probléme avec la lecture du dossier</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="628"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copie%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="635"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copie (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="663"/>
        <location filename="../../TransferThread.cpp" line="904"/>
        <source>File not found</source>
        <translation>Fichier non trouvé</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="188"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="904"/>
        <location filename="../../TransferThread.cpp" line="940"/>
        <source>Unable to change the date</source>
        <translation>Impossible de changer la date</translation>
    </message>
</context>
<context>
    <name>TransferThreadAsync</name>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="342"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation>Mauvaise date de modification ou impossible de l&apos;avoir, vous pouvez désactiver le transfert de celui-ci</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="436"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="454"/>
        <source>Unable to create the destination folder: </source>
        <translation>Impossible de créer le dossier de destination: </translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="439"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="456"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation>Impossible de créer le dossier de destination, errno: %1</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../async/WriteThread.cpp" line="138"/>
        <source>Path resolution error (Empty path)</source>
        <translation>Erreur de résolution de chemin (chemin vide)</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="167"/>
        <location filename="../../async/WriteThread.cpp" line="200"/>
        <source>Unable to create the destination folder: </source>
        <translation>Impossible de créer le dossier de destination: </translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="178"/>
        <location filename="../../async/WriteThread.cpp" line="202"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation>Impossible de créer le dossier de destination, errno: %1</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="464"/>
        <source>Internal error, please report it!</source>
        <translation>Erreur interne, veuillez la signaler!</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>Transfert</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="63"/>
        <source>Move the whole folder</source>
        <translation>Déplacer le dossier complet</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="97"/>
        <source>Transfer the file rights</source>
        <translation>Transférer les droits des fichiers</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="76"/>
        <source>Keep the file date</source>
        <translation>Garder la date du fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="114"/>
        <source>Create full path if not exists</source>
        <translation>Créer le dossier complet si il n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="138"/>
        <source>Checksum</source>
        <translation>Somme de contrôle</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Auto start</source>
        <translation>Démarrage automatique</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="154"/>
        <source>Error and collision</source>
        <translation>Erreur et collision</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="160"/>
        <source>When folder error</source>
        <translation>En cas d&apos;erreur de répertoire</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="170"/>
        <source>When file error</source>
        <translation>En cas d&apos;erreur de fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="196"/>
        <source>When file collision</source>
        <translation>En cas de collision de fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="239"/>
        <source>Overwrite if not same size</source>
        <translation>Écraser si pas la même taille</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="244"/>
        <source>Overwrite if modification date differs</source>
        <translation>Écraser si les dates différes</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="266"/>
        <source>When folder collision</source>
        <translation>Lors d&apos;une collision de dossier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="297"/>
        <source>Check if destination folder exists</source>
        <translation>Vérifier si le répertoire de destination existe</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="304"/>
        <source>Renaming rules</source>
        <translation>Règles de renommage</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="324"/>
        <source>Delete partially transferred files</source>
        <translation>Supprimer les transferts partiels</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="337"/>
        <source>Rename the original destination</source>
        <translation>Renommer la destination originale</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="368"/>
        <source>Performance</source>
        <translation>Performance</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="387"/>
        <source>Inode threads</source>
        <translation>Threads d&apos;inodes</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="397"/>
        <location filename="../../copyEngineOptions.ui" line="413"/>
        <source>MB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="429"/>
        <source>Uncheck this under Windows create problem</source>
        <translation>Décochez ceci sous Windows créer un problème</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="436"/>
        <source>OS Buffer</source>
        <translation>Tampon du système d&apos;exploitation</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="456"/>
        <source>Disable parallel transfer when are different devices</source>
        <translation>Désactiver le transfert parallèle lorsque différents appareils</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="463"/>
        <source>Buffer for different device</source>
        <translation>Tampon pour différents appareils</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="470"/>
        <source>OS FLags</source>
        <translation>Drapeaux du système d&apos;exploitation</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="477"/>
        <source>Buffer for same device</source>
        <translation>Tampon pour le même appareil</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="484"/>
        <source>OS native copy (disable speed limitation)</source>
        <translation>Copie native du système d&apos;exploitation (désactiver la limitation de vitesse)</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="514"/>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="520"/>
        <source>Check the disk space</source>
        <translation>Vérifier l&apos;espace disque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="530"/>
        <source>Use this folder when destination is not set</source>
        <translation>Utiliser ce dossier quand la destination n&apos;est pas défini</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="542"/>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="564"/>
        <source>Filters</source>
        <translation>Filtres</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>Erreur avec un fichier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>Essayer avec des priviléges suppérieurs</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>Le fichier existe</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if source newer than destination</source>
        <translation>Écraser si la source est plus récente que la destination</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>Écraser si les dates différes</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <source>Overwrite if source older than destination</source>
        <translation>Écraser si la source est antérieure à la destination</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if destination older</source>
        <translation>Écraser si destination plus ancienne</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="362"/>
        <location filename="../../fileExistsDialog.ui" line="365"/>
        <source>Overwrite if not same size</source>
        <translation>Écraser si pas la même taille</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="370"/>
        <location filename="../../fileExistsDialog.ui" line="373"/>
        <source>Overwrite if not same size and date</source>
        <translation>Remplacer si ce n&apos;est pas la même taille et la même date</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Écraser</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>La source et la destination sont identique</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>La source et la destination sont identique</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>Nom de répertoire</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
</TS>
